maxmedia_video_native library
Classes
- CapabilityReport
- CompressionResult
- ImageCompressionRequest
- MaxmediaVideoNative
- VideoBatchController
- Compresses a video queue one at a time.
- VideoBatchState
- Immutable snapshot pushed on VideoBatchController.stateStream.
- VideoCompressionProgress
- VideoCompressionRequest
- VideoQueueItemState
- Visible state of one queued video, in input order.
- VideoSourceSelection
Enums
- CompressionTerminal
- ContainerFormat
- ImageColorPolicy
- Controls whether an image may be exported when its color space changes.
- ImageFormat
- ImageResizePolicy
- Controls whether image pixels are kept at their original dimensions or resized with a social-sharing policy before encoding.
- MediaRouteKind
- VideoCodec
- VideoHdrPolicy
- Controls what an executor should do with an HDR video source.
- VideoQueueItemStatus
- Lifecycle of one video inside a VideoBatchController queue.
Functions
-
enumByName<
T extends Enum> (Iterable< T> values, Object? raw, String field) → T