MaxmediaVideoNative class
Constructors
- MaxmediaVideoNative()
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
progress
→ Stream<
VideoCompressionProgress> -
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
cancel(
) → Future< void> -
capabilities(
) → Future< CapabilityReport> -
compress(
VideoCompressionRequest request) → Future< CompressionResult> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
pickVideoSource(
) → Future< VideoSourceSelection?> -
pickVideoSources(
) → Future< List< VideoSourceSelection> > - Multi-select photo-library picker resolving every pick with the same direct-access policy as pickVideoSource.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited